package cn.com.ctop.toutiao.modules.report.controller;

import cn.com.ctop.toutiao.modules.report.entity.BytedanceVideoEtlInfo;
import cn.com.ctop.toutiao.modules.report.service.IBytedanceVideoEtlInfoService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;

 /**
 * 头条视频数据清洗信息
 * @author jeecg-boot
 * @date   2020-12-21
 * @version V1.0
 */
@Slf4j
@Api(tags="头条视频数据清洗信息")
@RestController
@RequestMapping("/ctop/bytedanceVideoEtlInfo")
public class BytedanceVideoEtlInfoController {
	@Autowired
	private IBytedanceVideoEtlInfoService bytedanceVideoEtlInfoService;

	/**
	  * 分页列表查询
	 * @param bytedanceVideoEtlInfo
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	@ApiOperation(value="头条视频数据清洗信息-分页列表查询", notes="头条视频数据清洗信息-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<BytedanceVideoEtlInfo>> queryPageList(BytedanceVideoEtlInfo bytedanceVideoEtlInfo,
															  @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
															  @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
															  HttpServletRequest req) {
		Result<IPage<BytedanceVideoEtlInfo>> result = new Result<>();
		QueryWrapper<BytedanceVideoEtlInfo> queryWrapper = QueryGenerator.initQueryWrapper(bytedanceVideoEtlInfo, req.getParameterMap());
		Page<BytedanceVideoEtlInfo> page = new Page<BytedanceVideoEtlInfo>(pageNo, pageSize);
		IPage<BytedanceVideoEtlInfo> pageList = bytedanceVideoEtlInfoService.page(page, queryWrapper);
		result.setSuccess(true);
		result.setResult(pageList);
		return result;
	}

	/**
	  *   添加
	 * @param bytedanceVideoEtlInfo
	 * @return
	 */
	@ApiOperation(value="头条视频数据清洗信息-添加", notes="头条视频数据清洗信息-添加")
	@PostMapping(value = "/add")
	public Result<BytedanceVideoEtlInfo> add(@RequestBody BytedanceVideoEtlInfo bytedanceVideoEtlInfo) {
		Result<BytedanceVideoEtlInfo> result = new Result<>();
		try {
			bytedanceVideoEtlInfoService.save(bytedanceVideoEtlInfo);
			result.success("添加成功！");
		} catch (Exception e) {
			log.error(e.getMessage(),e);
			result.error500("操作失败");
		}
		return result;
	}

	/**
	  *  编辑
	 * @param bytedanceVideoEtlInfo
	 * @return
	 */
	@ApiOperation(value="头条视频数据清洗信息-编辑", notes="头条视频数据清洗信息-编辑")
	@PutMapping(value = "/edit")
	public Result<BytedanceVideoEtlInfo> edit(@RequestBody BytedanceVideoEtlInfo bytedanceVideoEtlInfo) {
		Result<BytedanceVideoEtlInfo> result = new Result<BytedanceVideoEtlInfo>();
		BytedanceVideoEtlInfo bytedanceVideoEtlInfoEntity = bytedanceVideoEtlInfoService.getById(bytedanceVideoEtlInfo.getId());
		if(bytedanceVideoEtlInfoEntity==null) {
			result.error500("未找到对应实体");
		}else {
			boolean ok = bytedanceVideoEtlInfoService.updateById(bytedanceVideoEtlInfo);
			if(ok) {
				result.success("修改成功!");
			}
		}

		return result;
	}

	/**
	  *   通过id删除
	 * @param id
	 * @return
	 */
	@ApiOperation(value="头条视频数据清洗信息-通过id删除", notes="头条视频数据清洗信息-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		try {
			bytedanceVideoEtlInfoService.removeById(id);
		} catch (Exception e) {
			log.error("删除失败",e.getMessage());
			return Result.error("删除失败!");
		}
		return Result.ok("删除成功!");
	}

	/**
	  *  批量删除
	 * @param ids
	 * @return
	 */
	@ApiOperation(value="头条视频数据清洗信息-批量删除", notes="头条视频数据清洗信息-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<BytedanceVideoEtlInfo> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		Result<BytedanceVideoEtlInfo> result = new Result<>();
		if(ids==null || "".equals(ids.trim())) {
			result.error500("参数不识别！");
		}else {
			this.bytedanceVideoEtlInfoService.removeByIds(Arrays.asList(ids.split(",")));
			result.success("删除成功!");
		}
		return result;
	}

	/**
	  * 通过id查询
	 * @param id
	 * @return
	 */
	@ApiOperation(value="头条视频数据清洗信息-通过id查询", notes="头条视频数据清洗信息-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<BytedanceVideoEtlInfo> queryById(@RequestParam(name="id",required=true) String id) {
		Result<BytedanceVideoEtlInfo> result = new Result<>();
		BytedanceVideoEtlInfo bytedanceVideoEtlInfo = bytedanceVideoEtlInfoService.getById(id);
		if(bytedanceVideoEtlInfo==null) {
			result.error500("未找到对应实体");
		}else {
			result.setResult(bytedanceVideoEtlInfo);
			result.setSuccess(true);
		}
		return result;
	}
}
